import * as WebFont from 'webfontloader';
import { of, Subject } from 'rxjs';
import { catchError, debounceTime, distinctUntilChanged } from 'rxjs/operators';
import * as i3 from '@angular/forms';
import { FormControl, FormsModule, ReactiveFormsModule } from '@angular/forms';
import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, Pipe, Component, ViewEncapsulation, ViewChild, HostListener, EventEmitter, ReflectiveInjector, Directive, Input, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from 'ngx-scrollbar';
import { NgScrollbarModule } from 'ngx-scrollbar';
import * as i5 from 'ngx-scrollbar/reached-event';
import { NgScrollbarReachedModule } from 'ngx-scrollbar/reached-event';

const FONT_PICKER_CONFIG = new InjectionToken('FONT_PICKER_CONFIG');
class GoogleFontsInterface {
}
class Font {
    constructor(props) {
        this.size = '16px';
        this.style = 'regular';
        this.family = 'monospace';
        this.files = null;
        this.styles = ['regular'];
        if (props) {
            this.size = props.size || '16px';
            this.style = props.style || 'regular';
            this.family = props.family || 'monospace';
            this.files = props.files || null;
            this.styles = props.styles || ['regular'];
        }
    }
    getStyles() {
        return {
            'font-size': this.size || '16px',
            'font-style': this.style.includes('italic') ?
                'italic' : 'normal',
            'font-family': this.family || 'monospace',
            'font-weight': isNaN(Number(this.style.slice(0, 3))) ?
                'normal' : this.style.slice(0, 3)
        };
    }
}
class FontPickerConfig {
    constructor(config = {}) {
        this.apiKey = '';
        this.assign(config);
    }
    assign(config = {}) {
        for (const key in config) {
            this[key] = config[key];
        }
    }
}

class FontPickerService {
    constructor(http, _config) {
        this.http = http;
        this._config = _config;
        this.apiKey = '';
        this.baseUrl = 'https://www.googleapis.com/webfonts/v1/webfonts';
        this.apiKey = _config.apiKey || '';
    }
    /**
     * Loads the given font from Google Web Fonts.
     */
    loadFont(font) {
        try {
            WebFont.load({
                google: {
                    families: [font.family + ':' + font.style]
                }
            });
        }
        catch (e) {
            console.warn('Failed to load the font:', font);
        }
    }
    /**
     * Returns list of all fonts with given sort option:
     * date || alpha || style || trending || popularity
     */
    getAllFonts(sort) {
        if (!this.apiKey) {
            return of(null);
        }
        else {
            let requestUrl = this.baseUrl + '?key=' + this.apiKey;
            if (sort) {
                requestUrl = requestUrl.concat('&sort=' + sort);
            }
            return this.http.get(requestUrl).pipe(catchError(this.handleHttpError));
        }
    }
    /**
     * Returns font object for the requested font family.
     */
    getRequestedFont(family) {
        const requestUrl = 'https://fonts.googleapis.com/css?family=' + family;
        return this.http.get(requestUrl).pipe(catchError(this.handleHttpError));
    }
    /**
     * Handler method for all possible http request errors.
     */
    handleHttpError(error) {
        console.error(error);
        const errMsg = (error.error instanceof Error) ?
            error.error.message : (error.status || 'Unknown error');
        return of(errMsg);
    }
}
FontPickerService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerService, deps: [{ token: i1.HttpClient }, { token: FONT_PICKER_CONFIG }], target: i0.ɵɵFactoryTarget.Injectable });
FontPickerService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.HttpClient }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [FONT_PICKER_CONFIG]
                }] }]; } });

class FontSizePipe {
    transform(value) {
        return value ? parseInt(value.replace(/[^-\d\.]/g, '') || '16', 10) : 0;
    }
}
FontSizePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontSizePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
FontSizePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.3", ngImport: i0, type: FontSizePipe, name: "FontSize" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontSizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'FontSize',
                    pure: true
                }]
        }] });
class FontStylesPipe {
    transform(value) {
        const lookup = {
            '100': 'Thin',
            '200': 'Extra-Light',
            '300': 'Light',
            '400': 'Regular',
            '500': 'Medium',
            '600': 'Semi-bold',
            '700': 'Bold',
            '800': 'Extra-bold',
            '900': 'Black'
        };
        for (const style in lookup) {
            const found = value && value.search(style);
            if (found >= 0 && value != null) {
                value = value.replace(style, lookup[style] + ' ');
                break;
            }
        }
        return value;
    }
}
FontStylesPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontStylesPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
FontStylesPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.3", ngImport: i0, type: FontStylesPipe, name: "FontStyles" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontStylesPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'FontStyles',
                    pure: true
                }]
        }] });
class StatefulSlicePipe {
    constructor() {
        this.slicedArray = [];
        this.previousArrayRef = [];
        this.previousEndValue = 0;
    }
    transform(arr, start, end) {
        if (arr && (this.previousEndValue !== end || this.previousArrayRef !== arr)) {
            this.slicedArray = arr.slice(start, end);
            this.previousArrayRef = arr;
            this.previousEndValue = end;
        }
        return this.slicedArray || arr;
    }
}
StatefulSlicePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: StatefulSlicePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
StatefulSlicePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "14.2.3", ngImport: i0, type: StatefulSlicePipe, name: "StatefulSlice", pure: false });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: StatefulSlicePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'StatefulSlice',
                    pure: false
                }]
        }] });

class FontPickerComponent {
    constructor(cdRef, elRef, service) {
        this.cdRef = cdRef;
        this.elRef = elRef;
        this.service = service;
        this.useRootViewContainer = false;
        this.safeFonts = [
            'Arial',
            'sans-serif',
            'Times',
            'serif',
            'Courier',
            'monospace'
        ];
        this.fontAmount = 10;
        this.loadedFonts = 0;
        this.presetFonts = [];
        this.googleFonts = [];
        this.currentFonts = [];
        this.fpFilterByFamilies = [];
        this.fpSortByFamilies = false;
        this.dialogArrowSize = 10;
        this.dialogArrowOffset = 15;
        this.searchTerm = new FormControl('');
        this.renderMore = new Subject();
        this.loading = true;
        this.selectedFont = false;
        this.presetVisible = true;
    }
    handleEsc(event) {
        if (this.open && this.fpDialogDisplay === 'popup') {
            this.onCancelSelect(event);
        }
    }
    handleEnter(event) {
        if (this.open && this.fpDialogDisplay === 'popup') {
            this.onAcceptSelect(event);
        }
    }
    ngOnInit() {
        this.renderMore.pipe(debounceTime(150)).subscribe(() => this.loadMoreFonts());
        this.searchTerm.valueChanges.pipe(debounceTime(500), distinctUntilChanged()).subscribe((text) => {
            if (!text) {
                this.presetVisible = true;
                this.listLabel = this.fpPopularLabel;
            }
            else {
                this.presetVisible = false;
                this.listLabel = this.fpResultsLabel;
            }
            this.searchGoogleFonts(text);
        });
        this.testContainer = document.createElement('span');
        this.testContainer.innerHTML = Array(100).join('wi');
        this.testContainer.style.cssText = [
            'position: absolute',
            'left: -99999px',
            'width: auto',
            'font-size: 128px'
        ].join(' !important;');
        this.listenerResize = () => this.onResize();
        this.listenerMouseDown = (event) => this.onMouseDown(event);
        this.openFontPicker();
    }
    trackFont(index, font) {
        return font.family || index.toString();
    }
    setDialog(instance, elementRef, fpUseRootViewContainer, defaultFont, fpWidth, fpHeight, fpDialogDisplay, fpSizeSelect, fpStyleSelect, fpPosition, fpPositionOffset, fpPositionRelativeToArrow, fpSearchText, fpLoadingText, fpPopularLabel, fpResultsLabel, fpPresetLabel, fpPresetFonts, fpPresetNotice, fpCancelButton, fpCancelButtonText, fpCancelButtonClass, fpUploadButton, fpUploadButtonText, fpUploadButtonClass, fpFilterByFamilies, fpSortByFamilies) {
        this.listLabel = fpLoadingText;
        this.directiveInstance = instance;
        this.directiveElementRef = elementRef;
        this.useRootViewContainer = fpUseRootViewContainer;
        this.updateDialog(defaultFont, fpWidth, fpHeight, fpDialogDisplay, fpSizeSelect, fpStyleSelect, fpPosition, fpPositionOffset, fpPositionRelativeToArrow, fpSearchText, fpLoadingText, fpPopularLabel, fpResultsLabel, fpPresetLabel, fpPresetFonts, fpPresetNotice, fpCancelButton, fpCancelButtonText, fpCancelButtonClass, fpUploadButton, fpUploadButtonText, fpUploadButtonClass, fpFilterByFamilies, fpSortByFamilies);
        this.service.getAllFonts('popularity').subscribe((fonts) => {
            this.loading = false;
            if (fonts) {
                if (fonts.items) {
                    this.googleFonts = fonts.items.map((font) => {
                        return new Font({
                            files: font.files,
                            family: font.family,
                            styles: font.variants
                        });
                    });
                }
                if (fpFilterByFamilies?.length) {
                    this.googleFonts = this.googleFonts.filter((font) => fpFilterByFamilies.includes(font.family));
                }
                if (fpSortByFamilies) {
                    this.googleFonts = this.googleFonts.sort((a, b) => a.family < b.family ? -1 : 1);
                }
                // Find styles for initial font
                const searchFont = this.findFont(this.initialFont.family, true);
                if (searchFont) {
                    this.font.files = searchFont.files;
                    this.font.styles = searchFont.styles;
                    this.loadGoogleFonts([this.font]);
                }
                // Load Open Sans if available
                const openSans = this.googleFonts.find((font) => font.family === 'Open sans');
                if (openSans) {
                    this.loadGoogleFonts([openSans]);
                }
                this.setCurrentFonts(this.getPresetFonts().concat(this.googleFonts));
            }
            else {
                this.setCurrentFonts(this.getPresetFonts());
            }
        }, (error) => console.error(error));
    }
    updateDialog(font, fpWidth, fpHeight, fpDialogDisplay, fpSizeSelect, fpStyleSelect, fpPosition, fpPositionOffset, fpPositionRelativeToArrow, fpSearchText, fpLoadingText, fpPopularLabel, fpResultsLabel, fpPresetLabel, fpPresetFonts, fpPresetNotice, fpCancelButton, fpCancelButtonText, fpCancelButtonClass, fpUploadButton, fpUploadButtonText, fpUploadButtonClass, fpFilterByFamilies, fpSortByFamilies) {
        this.selectedFont = !!font;
        this.font = new Font(font);
        this.initialFont = new Font(font);
        this.fpPosition = fpPosition;
        this.fpPositionOffset = parseInt(fpPositionOffset, 10);
        if (!fpPositionRelativeToArrow) {
            this.dialogArrowOffset = 0;
        }
        if (fpDialogDisplay === 'inline') {
            this.dialogArrowSize = 0;
            this.dialogArrowOffset = 0;
        }
        this.fpSearchText = fpSearchText;
        this.fpLoadingText = fpLoadingText;
        this.fpPopularLabel = fpPopularLabel;
        this.fpResultsLabel = fpResultsLabel;
        this.fpSizeSelect = fpSizeSelect;
        this.fpStyleSelect = fpStyleSelect;
        this.fpPresetLabel = fpPresetLabel;
        this.fpPresetFonts = fpPresetFonts;
        this.fpPresetNotice = fpPresetNotice;
        this.fpCancelButton = fpCancelButton;
        this.fpCancelButtonText = fpCancelButtonText;
        this.fpCancelButtonClass = fpCancelButtonClass;
        this.fpUploadButton = fpUploadButton;
        this.fpUploadButtonText = fpUploadButtonText;
        this.fpUploadButtonClass = fpUploadButtonClass;
        this.fpFilterByFamilies = fpFilterByFamilies;
        this.fpSortByFamilies = fpSortByFamilies;
        this.autoWidth = fpWidth === 'auto';
        this.fpWidth = parseInt(fpWidth, 10);
        this.fpHeight = parseInt(fpHeight, 10);
        this.fpDialogDisplay = fpDialogDisplay;
        this.setCurrentFonts(this.getPresetFonts().concat(this.googleFonts));
        this.searchTerm.reset({ value: '', disabled: (this.fpPresetFonts.length > 0) });
    }
    openFontPicker() {
        if (!this.open) {
            this.setDialogPosition();
            this.searchTerm.setValue('');
            window.addEventListener('resize', this.listenerResize);
            document.addEventListener('mousedown', this.listenerMouseDown);
            this.open = true;
        }
    }
    closeFontPicker() {
        this.open = false;
        window.removeEventListener('resize', this.listenerResize);
        document.removeEventListener('mousedown', this.listenerMouseDown);
    }
    isFontAvailable(font) {
        if (!this.testWidth) {
            this.testContainer.style.fontFamily = 'monospace';
            document.body.appendChild(this.testContainer);
            this.testWidth = this.testContainer.clientWidth;
            document.body.removeChild(this.testContainer);
        }
        this.testContainer.style.fontFamily = font.family + ', monospace';
        document.body.appendChild(this.testContainer);
        const width = this.testContainer.clientWidth;
        document.body.removeChild(this.testContainer);
        return width !== this.testWidth;
    }
    getPresetFonts() {
        const presetFonts = [];
        if (this.googleFonts && this.fpPresetFonts && this.fpPresetFonts.length) {
            this.fpPresetFonts.forEach((font) => {
                let fontClass = this.findFont(font, true);
                if (!fontClass) {
                    fontClass = new Font({
                        family: font,
                        styles: ['regular', 'italic']
                    });
                }
                presetFonts.push(fontClass);
            });
            this.presetFonts = presetFonts;
        }
        return presetFonts;
    }
    setCurrentFonts(target) {
        if (target !== this.currentFonts) {
            this.currentFonts = target;
            this.loadedFonts = this.fontAmount;
            const initialFonts = this.currentFonts.slice(0, this.fontAmount);
            this.loadGoogleFonts(initialFonts);
            this.cdRef.markForCheck();
            setTimeout(() => {
                if (this.scrollbar) {
                    this.scrollbar.scrollTo({ top: 0 });
                }
            }, 0);
        }
    }
    findFont(searchVal, exactMatch = false) {
        return this.findFonts(searchVal, exactMatch)[0];
    }
    findFonts(searchVal, exactMatch = false) {
        const fullmatchFonts = [];
        const candidateFonts = [];
        searchVal = searchVal.toLowerCase();
        this.googleFonts.forEach((font) => {
            if (searchVal === font.family.toLowerCase()) {
                fullmatchFonts.push(font);
                return;
            }
            if (!exactMatch && font.family.toLowerCase().indexOf(searchVal) > -1) {
                candidateFonts.push(font);
            }
        });
        const resultFonts = fullmatchFonts.concat(candidateFonts);
        return resultFonts;
    }
    loadMoreFonts() {
        if (this.open && !this.loading && this.loadedFonts < this.currentFonts.length) {
            const moreFonts = this.currentFonts.slice(this.loadedFonts, this.loadedFonts + this.fontAmount);
            this.loadGoogleFonts(moreFonts);
            this.loadedFonts += moreFonts.length;
            this.cdRef.markForCheck();
            this.cdRef.detectChanges();
        }
    }
    loadGoogleFonts(fonts) {
        fonts.slice(0, this.fontAmount).forEach((font) => {
            if (font && font.files && !this.isFontAvailable(font)) {
                const style = (font.styles.indexOf('regular') > -1) ?
                    '' : ':' + font.styles.find((x) => !isNaN(x));
                this.service.loadFont({ family: font.family, style: style, size: font.size });
            }
        });
    }
    searchGoogleFonts(value) {
        if (!value) {
            this.searchTerm.setValue('');
            this.setCurrentFonts(this.googleFonts);
        }
        else {
            value = value.toLowerCase();
            if (this.googleFonts) {
                this.loadedFonts = this.fontAmount;
                const searchResult = this.findFonts(value, false);
                this.setCurrentFonts(searchResult);
                this.cdRef.markForCheck();
            }
        }
    }
    isDescendant(parent, child) {
        let node = child.parentNode;
        while (node !== null) {
            if (node === parent) {
                return true;
            }
            node = node.parentNode;
        }
        return false;
    }
    createDialogBox(element, offset) {
        return {
            top: element.getBoundingClientRect().top + (offset ? window.pageYOffset : 0),
            left: element.getBoundingClientRect().left + (offset ? window.pageXOffset : 0),
            width: element.offsetWidth,
            height: element.offsetHeight
        };
    }
    setDialogPosition() {
        if (this.fpDialogDisplay === 'inline') {
            this.position = 'relative';
        }
        else {
            let position = 'static', transform = '', style;
            let parentNode = null, transformNode = null;
            let node = this.directiveElementRef.nativeElement.parentNode;
            const dialogHeight = this.dialogElement.nativeElement.offsetHeight;
            while (node !== null && node.tagName !== 'HTML') {
                style = window.getComputedStyle(node);
                position = style.getPropertyValue('position');
                transform = style.getPropertyValue('transform');
                if (position !== 'static' && parentNode === null) {
                    parentNode = node;
                }
                if (transform && transform !== 'none' && transformNode === null) {
                    transformNode = node;
                }
                if (position === 'fixed') {
                    parentNode = transformNode;
                    break;
                }
                node = node.parentNode;
            }
            const boxDirective = this.createDialogBox(this.directiveElementRef.nativeElement, (position !== 'fixed'));
            if (this.autoWidth) {
                this.fpWidth = this.directiveElementRef.nativeElement.offsetWidth;
            }
            if (this.useRootViewContainer || (position === 'fixed' &&
                (!parentNode || parentNode instanceof HTMLUnknownElement))) {
                this.top = boxDirective.top;
                this.left = boxDirective.left;
            }
            else {
                if (parentNode === null) {
                    parentNode = node;
                }
                const boxParent = this.createDialogBox(parentNode, (position !== 'fixed'));
                this.top = boxDirective.top - boxParent.top;
                this.left = boxDirective.left - boxParent.left;
            }
            if (position === 'fixed') {
                this.position = 'fixed';
            }
            if (this.fpPosition === 'left') {
                this.top += boxDirective.height * this.fpPositionOffset / 100 - this.dialogArrowOffset;
                this.left -= this.fpWidth + this.dialogArrowSize - 2;
            }
            else if (this.fpPosition === 'top') {
                this.arrowTop = dialogHeight - 1;
                this.top -= dialogHeight + this.dialogArrowSize;
                this.left += this.fpPositionOffset / 100 * boxDirective.width - this.dialogArrowOffset;
            }
            else if (this.fpPosition === 'bottom') {
                this.top += boxDirective.height + this.dialogArrowSize;
                this.left += this.fpPositionOffset / 100 * boxDirective.width - this.dialogArrowOffset;
            }
            else {
                this.top += boxDirective.height * this.fpPositionOffset / 100 - this.dialogArrowOffset;
                this.left += boxDirective.width + this.dialogArrowSize - 2;
            }
        }
    }
    onResize() {
        if (this.position === 'fixed') {
            this.setDialogPosition();
        }
        else if (this.fpDialogDisplay !== 'inline') {
            this.closeFontPicker();
        }
    }
    onMouseDown(event) {
        if (this.fpDialogDisplay === 'popup' &&
            event.target !== this.directiveElementRef.nativeElement &&
            !this.isDescendant(this.elRef.nativeElement, event.target) &&
            !this.isDescendant(this.directiveElementRef.nativeElement, event.target)) {
            this.closeFontPicker();
            this.cdRef.markForCheck();
        }
    }
    onUploadFont(event) {
        event.stopPropagation();
        this.directiveInstance.uploadFont();
    }
    onAcceptSelect(event) {
        event.stopPropagation();
        this.directiveInstance.fontChanged(this.font);
        if (this.fpDialogDisplay === 'popup') {
            this.closeFontPicker();
        }
    }
    onCancelSelect(event) {
        event.stopPropagation();
        this.selectedFont = false;
        this.font.size = this.initialFont.size;
        this.font.files = this.initialFont.files;
        this.font.style = this.initialFont.style;
        this.font.family = this.initialFont.family;
        this.font.styles = this.initialFont.styles;
        this.directiveInstance.fontChanged(this.font);
        if (this.fpDialogDisplay === 'popup') {
            this.closeFontPicker();
        }
    }
    onSelectFont(font) {
        this.selectedFont = true;
        this.font.files = font.files;
        this.font.family = font.family;
        this.font.styles = font.styles;
        this.font.style = (font.styles.indexOf('regular') !== -1) ?
            'regular' : font.styles[0];
        this.directiveInstance.fontChanged(this.font);
        this.cdRef.markForCheck();
        this.cdRef.detectChanges();
    }
    onSearchReset(event) {
        event.stopPropagation();
        this.searchTerm.setValue('');
        this.setCurrentFonts(this.googleFonts);
    }
    onFontSizeChange(event) {
        this.font.size = event.target.value + 'px';
        this.directiveInstance.fontChanged(this.font);
    }
    onFontStyleChange(event, font) {
        const str = this.font.family + ':' + event.target.value;
        if (font.files) {
            WebFont.load({
                google: {
                    families: [str]
                }
            });
        }
        this.directiveInstance.fontChanged(this.font);
    }
}
FontPickerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerComponent, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: FontPickerService }], target: i0.ɵɵFactoryTarget.Component });
FontPickerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.3", type: FontPickerComponent, selector: "font-picker", host: { listeners: { "document:keyup.esc": "handleEsc($event)", "document:keyup.enter": "handleEnter($event)" } }, viewQueries: [{ propertyName: "dialogElement", first: true, predicate: ["dialogPopup"], descendants: true, static: true }, { propertyName: "scrollbar", first: true, predicate: ["dialogScrollbar"], descendants: true, static: true }], ngImport: i0, template: "<div #dialogPopup class=\"font-picker\" [style.visibility]=\"!open ? 'hidden' : 'visible'\" [style.height.px]=\"fpHeight\" [style.width.px]=\"fpWidth\" [style.top.px]=\"top\" [style.left.px]=\"left\" [style.position]=\"position\">\n  <div *ngIf=\"fpDialogDisplay === 'popup'\" class=\"arrow arrow-{{fpPosition}}\" [style.top.px]=\"arrowTop\"></div>\n\n  <div *ngIf=\"googleFonts.length\" class=\"search-box\">\n    <input class=\"search-field\" placeholder=\"{{fpSearchText || ''}}\" [formControl]=\"searchTerm\" />\n\n    <div class=\"search-reset\" [hidden]=\"!searchTerm.value\" (click)=\"onSearchReset($event)\">\u00D7</div>\n  </div>\n\n  <div *ngIf=\"loading\" class=\"load-text\">{{fpLoadingText || ''}}</div>\n\n  <ng-scrollbar #dialogScrollbar class=\"font-list\" [attr.fxFlex]=\"'auto'\" (reachedBottom)=\"renderMore.next($event)\">\n    <div *ngIf=\"presetVisible && fpPresetFonts.length\">\n      <div class=\"font-group\">\n        <div class=\"group-text\">{{fpPresetLabel || ''}}</div>\n        <div class=\"group-line\"></div>\n      </div>\n\n      <div *ngFor=\"let fontItem of presetFonts | StatefulSlice:0:loadedFonts; trackBy:trackFont\" class=\"font-item\" [ngClass]=\"{active: fontItem.family.toLowerCase() === font.family.toLowerCase(), selected: selectedFont}\" [ngStyle]=\"{'font-family': fontItem.family}\" (click)=\"onSelectFont(fontItem)\">\n        <div class=\"font-info\">\n          <span class=\"font-name\">{{fontItem.family || ''}}</span>\n\n          <div *ngIf=\"!fontItem.files && safeFonts.indexOf(fontItem.family) === -1 && googleFonts.length\" class=\"not-available\">\n            <span>!</span>\n\n            <div class=\"notice-text\">{{fpPresetNotice || 'This font is not from Google Fonts. If you select it, you might have to import it manually in your CSS rules.'}}</div>\n          </div>\n        </div>\n      </div>\n    </div>\n\n    <ng-container *ngIf=\"googleFonts.length\">\n      <div class=\"font-group\" *ngIf=\"!fpFilterByFamilies.length || fpPresetFonts.length\">\n        <div class=\"group-text black\">{{listLabel || ''}}</div>\n        <div class=\"group-line black\"></div>\n      </div>\n\n      <div *ngFor=\"let fontItem of (currentFonts | StatefulSlice:0:loadedFonts)\" class=\"font-item\" [ngClass]=\"{'active': fontItem.family.toLowerCase() === font.family.toLowerCase(), selected: selectedFont}\" [ngStyle]=\"{'font-family': fontItem.family}\" (click)=\"onSelectFont(fontItem)\">\n        <div class=\"font-info\">\n          <span class=\"font-name\">{{fontItem.family || ''}}</span>\n        </div>\n      </div>\n    </ng-container>\n  </ng-scrollbar>\n\n  <div *ngIf=\"selectedFont && (fpStyleSelect || fpSizeSelect)\">\n    <div  class=\"font-options\">\n      <div *ngIf=\"fpStyleSelect\" class=\"left\">\n        <select class=\"style-select\" [disabled]=\"!font.styles\" (change)=\"onFontStyleChange($event, font)\" [(ngModel)]=\"font.style\">\n          <option *ngFor=\"let style of font.styles\" [value]=\"style\">{{style | FontStyles}}</option>\n        </select>\n      </div>\n\n      <div *ngIf=\"fpSizeSelect\" class=\"right\">\n        <input type=\"number\" pattern=\"[0-9]*\" min=\"1\" max=\"100\" (change)=\"onFontSizeChange($event)\" [ngClass]=\"{'size-select': fpStyleSelect}\" [ngModel]=\"font.size | FontSize\" />\n      </div>\n    </div>\n  </div>\n\n  <div *ngIf=\"fpUploadButton || fpCancelButton\" class=\"button-area\">\n    <button *ngIf=\"fpUploadButton\" type=\"button\" class=\"{{fpUploadButtonClass}}\" (click)=\"onUploadFont($event)\">{{fpUploadButtonText || 'Upload'}}</button>\n\n    <button *ngIf=\"fpCancelButton\" type=\"button\" class=\"{{fpCancelButtonClass}}\" (click)=\"onCancelSelect($event)\">{{fpCancelButtonText || 'Cancel'}}</button>\n  </div>\n</div>\n", styles: [".font-picker{position:absolute;z-index:1000;top:250px;left:30px;display:flex;flex-direction:column;width:280px;height:320px;min-width:200px;min-height:240px;border:#777 solid 1px;cursor:default;-webkit-user-select:none;user-select:none;font-family:Open Sans,sans-serif;background-color:#fff}.font-picker[hidden]{display:none}.font-picker input,.font-picker select{width:100%;padding:4px;border:none;border-bottom:2px solid #cfcfcf;outline:none;font-size:14px;line-height:18px;text-align:left;background:none;transition:border .3s ease}.font-picker input:hover,.font-picker input:focus,.font-picker input:active,.font-picker select:hover,.font-picker select:focus,.font-picker select:active{border-bottom:2px solid #999}.font-picker input:invalid,.font-picker select:invalid{border-bottom:2px solid #e74c3c;box-shadow:none}.font-picker input::-webkit-inner-spin-button,.font-picker input::-webkit-outer-spin-button{margin:0;-webkit-appearance:none}.font-picker .arrow{position:absolute;z-index:999999;width:0;height:0;border-style:solid}.font-picker .arrow.arrow-left{top:10px;left:231px;border-width:5px 10px;border-color:rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0) #777}.font-picker .arrow.arrow-right{top:10px;left:-20px;border-width:5px 10px;border-color:rgba(0,0,0,0) #777 rgba(0,0,0,0) rgba(0,0,0,0)}.font-picker .arrow.arrow-top{top:0;left:10px;border-width:10px 5px;border-color:#777 rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0)}.font-picker .arrow.arrow-bottom{top:-20px;left:10px;border-width:10px 5px;border-color:rgba(0,0,0,0) rgba(0,0,0,0) #777 rgba(0,0,0,0)}.font-picker .search-box{position:relative}.font-picker .search-field{box-sizing:border-box;padding:10px 48px 10px 16px}.font-picker .search-field:disabled{opacity:.5;cursor:not-allowed;background-color:#888}.font-picker .search-reset{position:absolute;top:0;right:0;padding:1px 12px;cursor:pointer;font-size:31px;color:#777;transition:color .3s ease}.font-picker .search-reset:hover{color:#555}.font-picker .load-text{padding:16px;font-size:12px;text-align:center;color:#000}.font-picker .font-list{position:relative;overflow:hidden;flex:1 1 auto}.font-picker .font-list .font-item{position:relative;padding:8px 16px;cursor:pointer}.font-picker .font-list .font-item.active{font-weight:700}.font-picker .font-list .font-item.active.selected{cursor:default;font-weight:400;background:#d9d9d9}.font-picker .font-list .font-item .font-info{margin:4px 0}.font-picker .font-list .font-item .font-info .font-name{font-size:14px;text-transform:capitalize;color:#555}.font-picker .font-list .font-item .font-info .not-available{float:right;width:24px;margin:-8px -8px 0 0;font-size:24px;font-weight:900;font-family:Open Sans,sans-serif;text-align:center;text-transform:none;color:#ef8b80}.font-picker .font-list .font-item .font-info .not-available .notice-text{content:\"This font is not from Google Fonts. If you select it, you might have to import it manually in your CSS rules.\";position:absolute;z-index:10;top:0;right:12px;left:12px;opacity:0;padding:12px 16px;margin:0 auto;border-radius:2px;pointer-events:none;font-size:13px;font-weight:400;text-align:left;color:#fff;background:rgba(60,60,60,.8);transition:opacity .15s ease}.font-picker .font-list .font-item .font-info .not-available:hover{color:#ea6153}.font-picker .font-list .font-item .font-info .not-available:hover .notice-text{opacity:1}.font-picker .font-list .font-item .font-text{padding:4px 0;font-size:16px;text-align:right;color:#999}.font-picker .font-list .font-group{display:flex;flex:none}.font-picker .font-list .font-group .group-line{flex:1 1 auto;height:2px;margin-top:14px;margin-right:12px;background:#e74c3c}.font-picker .font-list .font-group .group-line.black{background:#000}.font-picker .font-list .font-group .group-text{overflow:hidden;box-sizing:border-box;max-width:75%;padding:8px 12px;font-size:11px;font-weight:700;white-space:nowrap;text-align:left;text-overflow:ellipsis;color:#e74c3c}.font-picker .font-list .font-group .group-text.black{color:#000}.font-picker .font-options{display:flex;box-sizing:border-box;padding:8px;border-top:2px solid #cfcfcf}.font-picker .font-options .left{flex:1 1 auto;padding:0 2px}.font-picker .font-options .left .style-select{text-transform:capitalize}.font-picker .font-options .left .style-select:disabled{background-color:#777}.font-picker .font-options .right{padding:0 2px}.font-picker .font-options .right .size-select{width:48px;text-align:center}.font-picker .button-area{padding:0 4px 4px;border-top:1px solid #aaa;text-align:right}.font-picker .button-area .fp-cancel-button-class,.font-picker .button-area .fp-upload-button-class{display:inline-block;margin:8px;text-align:center;text-transform:uppercase}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "directive", type: i3.NgSelectOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i3.ɵNgSelectMultipleOption, selector: "option", inputs: ["ngValue", "value"] }, { kind: "directive", type: i3.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i3.NumberValueAccessor, selector: "input[type=number][formControlName],input[type=number][formControl],input[type=number][ngModel]" }, { kind: "directive", type: i3.SelectControlValueAccessor, selector: "select:not([multiple])[formControlName],select:not([multiple])[formControl],select:not([multiple])[ngModel]", inputs: ["compareWith"] }, { kind: "directive", type: i3.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i3.PatternValidator, selector: "[pattern][formControlName],[pattern][formControl],[pattern][ngModel]", inputs: ["pattern"] }, { kind: "directive", type: i3.MinValidator, selector: "input[type=number][min][formControlName],input[type=number][min][formControl],input[type=number][min][ngModel]", inputs: ["min"] }, { kind: "directive", type: i3.MaxValidator, selector: "input[type=number][max][formControlName],input[type=number][max][formControl],input[type=number][max][ngModel]", inputs: ["max"] }, { kind: "directive", type: i3.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "directive", type: i3.FormControlDirective, selector: "[formControl]", inputs: ["formControl", "disabled", "ngModel"], outputs: ["ngModelChange"], exportAs: ["ngForm"] }, { kind: "component", type: i4.NgScrollbar, selector: "ng-scrollbar", inputs: ["disabled", "sensorDisabled", "pointerEventsDisabled", "viewportPropagateMouseMove", "autoHeightDisabled", "autoWidthDisabled", "viewClass", "trackClass", "thumbClass", "minThumbSize", "trackClickScrollDuration", "pointerEventsMethod", "track", "visibility", "appearance", "position", "sensorDebounce", "scrollAuditTime"], outputs: ["updated"], exportAs: ["ngScrollbar"] }, { kind: "directive", type: i5.NgScrollbarReachedBottom, selector: "[reachedBottom], [reached-bottom]", outputs: ["reachedBottom"] }, { kind: "pipe", type: FontSizePipe, name: "FontSize" }, { kind: "pipe", type: FontStylesPipe, name: "FontStyles" }, { kind: "pipe", type: StatefulSlicePipe, name: "StatefulSlice" }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'font-picker', encapsulation: ViewEncapsulation.None, template: "<div #dialogPopup class=\"font-picker\" [style.visibility]=\"!open ? 'hidden' : 'visible'\" [style.height.px]=\"fpHeight\" [style.width.px]=\"fpWidth\" [style.top.px]=\"top\" [style.left.px]=\"left\" [style.position]=\"position\">\n  <div *ngIf=\"fpDialogDisplay === 'popup'\" class=\"arrow arrow-{{fpPosition}}\" [style.top.px]=\"arrowTop\"></div>\n\n  <div *ngIf=\"googleFonts.length\" class=\"search-box\">\n    <input class=\"search-field\" placeholder=\"{{fpSearchText || ''}}\" [formControl]=\"searchTerm\" />\n\n    <div class=\"search-reset\" [hidden]=\"!searchTerm.value\" (click)=\"onSearchReset($event)\">\u00D7</div>\n  </div>\n\n  <div *ngIf=\"loading\" class=\"load-text\">{{fpLoadingText || ''}}</div>\n\n  <ng-scrollbar #dialogScrollbar class=\"font-list\" [attr.fxFlex]=\"'auto'\" (reachedBottom)=\"renderMore.next($event)\">\n    <div *ngIf=\"presetVisible && fpPresetFonts.length\">\n      <div class=\"font-group\">\n        <div class=\"group-text\">{{fpPresetLabel || ''}}</div>\n        <div class=\"group-line\"></div>\n      </div>\n\n      <div *ngFor=\"let fontItem of presetFonts | StatefulSlice:0:loadedFonts; trackBy:trackFont\" class=\"font-item\" [ngClass]=\"{active: fontItem.family.toLowerCase() === font.family.toLowerCase(), selected: selectedFont}\" [ngStyle]=\"{'font-family': fontItem.family}\" (click)=\"onSelectFont(fontItem)\">\n        <div class=\"font-info\">\n          <span class=\"font-name\">{{fontItem.family || ''}}</span>\n\n          <div *ngIf=\"!fontItem.files && safeFonts.indexOf(fontItem.family) === -1 && googleFonts.length\" class=\"not-available\">\n            <span>!</span>\n\n            <div class=\"notice-text\">{{fpPresetNotice || 'This font is not from Google Fonts. If you select it, you might have to import it manually in your CSS rules.'}}</div>\n          </div>\n        </div>\n      </div>\n    </div>\n\n    <ng-container *ngIf=\"googleFonts.length\">\n      <div class=\"font-group\" *ngIf=\"!fpFilterByFamilies.length || fpPresetFonts.length\">\n        <div class=\"group-text black\">{{listLabel || ''}}</div>\n        <div class=\"group-line black\"></div>\n      </div>\n\n      <div *ngFor=\"let fontItem of (currentFonts | StatefulSlice:0:loadedFonts)\" class=\"font-item\" [ngClass]=\"{'active': fontItem.family.toLowerCase() === font.family.toLowerCase(), selected: selectedFont}\" [ngStyle]=\"{'font-family': fontItem.family}\" (click)=\"onSelectFont(fontItem)\">\n        <div class=\"font-info\">\n          <span class=\"font-name\">{{fontItem.family || ''}}</span>\n        </div>\n      </div>\n    </ng-container>\n  </ng-scrollbar>\n\n  <div *ngIf=\"selectedFont && (fpStyleSelect || fpSizeSelect)\">\n    <div  class=\"font-options\">\n      <div *ngIf=\"fpStyleSelect\" class=\"left\">\n        <select class=\"style-select\" [disabled]=\"!font.styles\" (change)=\"onFontStyleChange($event, font)\" [(ngModel)]=\"font.style\">\n          <option *ngFor=\"let style of font.styles\" [value]=\"style\">{{style | FontStyles}}</option>\n        </select>\n      </div>\n\n      <div *ngIf=\"fpSizeSelect\" class=\"right\">\n        <input type=\"number\" pattern=\"[0-9]*\" min=\"1\" max=\"100\" (change)=\"onFontSizeChange($event)\" [ngClass]=\"{'size-select': fpStyleSelect}\" [ngModel]=\"font.size | FontSize\" />\n      </div>\n    </div>\n  </div>\n\n  <div *ngIf=\"fpUploadButton || fpCancelButton\" class=\"button-area\">\n    <button *ngIf=\"fpUploadButton\" type=\"button\" class=\"{{fpUploadButtonClass}}\" (click)=\"onUploadFont($event)\">{{fpUploadButtonText || 'Upload'}}</button>\n\n    <button *ngIf=\"fpCancelButton\" type=\"button\" class=\"{{fpCancelButtonClass}}\" (click)=\"onCancelSelect($event)\">{{fpCancelButtonText || 'Cancel'}}</button>\n  </div>\n</div>\n", styles: [".font-picker{position:absolute;z-index:1000;top:250px;left:30px;display:flex;flex-direction:column;width:280px;height:320px;min-width:200px;min-height:240px;border:#777 solid 1px;cursor:default;-webkit-user-select:none;user-select:none;font-family:Open Sans,sans-serif;background-color:#fff}.font-picker[hidden]{display:none}.font-picker input,.font-picker select{width:100%;padding:4px;border:none;border-bottom:2px solid #cfcfcf;outline:none;font-size:14px;line-height:18px;text-align:left;background:none;transition:border .3s ease}.font-picker input:hover,.font-picker input:focus,.font-picker input:active,.font-picker select:hover,.font-picker select:focus,.font-picker select:active{border-bottom:2px solid #999}.font-picker input:invalid,.font-picker select:invalid{border-bottom:2px solid #e74c3c;box-shadow:none}.font-picker input::-webkit-inner-spin-button,.font-picker input::-webkit-outer-spin-button{margin:0;-webkit-appearance:none}.font-picker .arrow{position:absolute;z-index:999999;width:0;height:0;border-style:solid}.font-picker .arrow.arrow-left{top:10px;left:231px;border-width:5px 10px;border-color:rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0) #777}.font-picker .arrow.arrow-right{top:10px;left:-20px;border-width:5px 10px;border-color:rgba(0,0,0,0) #777 rgba(0,0,0,0) rgba(0,0,0,0)}.font-picker .arrow.arrow-top{top:0;left:10px;border-width:10px 5px;border-color:#777 rgba(0,0,0,0) rgba(0,0,0,0) rgba(0,0,0,0)}.font-picker .arrow.arrow-bottom{top:-20px;left:10px;border-width:10px 5px;border-color:rgba(0,0,0,0) rgba(0,0,0,0) #777 rgba(0,0,0,0)}.font-picker .search-box{position:relative}.font-picker .search-field{box-sizing:border-box;padding:10px 48px 10px 16px}.font-picker .search-field:disabled{opacity:.5;cursor:not-allowed;background-color:#888}.font-picker .search-reset{position:absolute;top:0;right:0;padding:1px 12px;cursor:pointer;font-size:31px;color:#777;transition:color .3s ease}.font-picker .search-reset:hover{color:#555}.font-picker .load-text{padding:16px;font-size:12px;text-align:center;color:#000}.font-picker .font-list{position:relative;overflow:hidden;flex:1 1 auto}.font-picker .font-list .font-item{position:relative;padding:8px 16px;cursor:pointer}.font-picker .font-list .font-item.active{font-weight:700}.font-picker .font-list .font-item.active.selected{cursor:default;font-weight:400;background:#d9d9d9}.font-picker .font-list .font-item .font-info{margin:4px 0}.font-picker .font-list .font-item .font-info .font-name{font-size:14px;text-transform:capitalize;color:#555}.font-picker .font-list .font-item .font-info .not-available{float:right;width:24px;margin:-8px -8px 0 0;font-size:24px;font-weight:900;font-family:Open Sans,sans-serif;text-align:center;text-transform:none;color:#ef8b80}.font-picker .font-list .font-item .font-info .not-available .notice-text{content:\"This font is not from Google Fonts. If you select it, you might have to import it manually in your CSS rules.\";position:absolute;z-index:10;top:0;right:12px;left:12px;opacity:0;padding:12px 16px;margin:0 auto;border-radius:2px;pointer-events:none;font-size:13px;font-weight:400;text-align:left;color:#fff;background:rgba(60,60,60,.8);transition:opacity .15s ease}.font-picker .font-list .font-item .font-info .not-available:hover{color:#ea6153}.font-picker .font-list .font-item .font-info .not-available:hover .notice-text{opacity:1}.font-picker .font-list .font-item .font-text{padding:4px 0;font-size:16px;text-align:right;color:#999}.font-picker .font-list .font-group{display:flex;flex:none}.font-picker .font-list .font-group .group-line{flex:1 1 auto;height:2px;margin-top:14px;margin-right:12px;background:#e74c3c}.font-picker .font-list .font-group .group-line.black{background:#000}.font-picker .font-list .font-group .group-text{overflow:hidden;box-sizing:border-box;max-width:75%;padding:8px 12px;font-size:11px;font-weight:700;white-space:nowrap;text-align:left;text-overflow:ellipsis;color:#e74c3c}.font-picker .font-list .font-group .group-text.black{color:#000}.font-picker .font-options{display:flex;box-sizing:border-box;padding:8px;border-top:2px solid #cfcfcf}.font-picker .font-options .left{flex:1 1 auto;padding:0 2px}.font-picker .font-options .left .style-select{text-transform:capitalize}.font-picker .font-options .left .style-select:disabled{background-color:#777}.font-picker .font-options .right{padding:0 2px}.font-picker .font-options .right .size-select{width:48px;text-align:center}.font-picker .button-area{padding:0 4px 4px;border-top:1px solid #aaa;text-align:right}.font-picker .button-area .fp-cancel-button-class,.font-picker .button-area .fp-upload-button-class{display:inline-block;margin:8px;text-align:center;text-transform:uppercase}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: FontPickerService }]; }, propDecorators: { dialogElement: [{
                type: ViewChild,
                args: ['dialogPopup', { static: true }]
            }], scrollbar: [{
                type: ViewChild,
                args: ['dialogScrollbar', { static: true }]
            }], handleEsc: [{
                type: HostListener,
                args: ['document:keyup.esc', ['$event']]
            }], handleEnter: [{
                type: HostListener,
                args: ['document:keyup.enter', ['$event']]
            }] } });

class FontPickerDirective {
    constructor(injector, resolver, appRef, vcRef, elRef, cdRef, service) {
        this.injector = injector;
        this.resolver = resolver;
        this.appRef = appRef;
        this.vcRef = vcRef;
        this.elRef = elRef;
        this.cdRef = cdRef;
        this.service = service;
        this.fpWidth = '280px';
        this.fpHeight = '320px';
        this.fpFallbackFont = {
            family: 'Roboto',
            size: '16px',
            style: 'regular',
            styles: ['regular']
        };
        this.fpAutoLoad = true;
        this.fpPresetLabel = '';
        this.fpPresetFonts = [];
        this.fpPresetNotice = '';
        this.fpSizeSelect = true;
        this.fpStyleSelect = true;
        this.fpDialogDisplay = 'popup';
        this.fpUseRootViewContainer = false;
        this.fpPosition = 'bottom';
        this.fpPositionOffset = '0%';
        this.fpPositionRelativeToArrow = false;
        this.fpSearchText = 'Search fonts...';
        this.fpLoadingText = 'Loading fonts...';
        this.fpPopularLabel = 'Popular fonts';
        this.fpResultsLabel = 'Search results';
        this.fpCancelButton = false;
        this.fpCancelButtonText = 'Cancel';
        this.fpCancelButtonClass = 'fp-cancel-button-class';
        this.fpUploadButton = false;
        this.fpUploadButtonText = 'Upload';
        this.fpUploadButtonClass = 'fp-upload-button-class';
        this.fpFilterByFamilies = [];
        this.fpSortByFamilies = false;
        this.fontPickerUpload = new EventEmitter();
        this.fontPickerChange = new EventEmitter();
    }
    onClick() {
        this.toggleDialog();
    }
    ngOnInit() {
        this.fontPicker = this.fontPicker || this.fpFallbackFont;
    }
    ngOnChanges(changes) {
        if (changes.fontPicker) {
            this.fontPicker = this.fontPicker || this.fpFallbackFont;
            if (this.fpAutoLoad) {
                this.loadFont(this.fontPicker);
            }
        }
        if (changes.fpSortByFamilies || changes.fpFilterByFamilies) {
            this.dialog = undefined;
        }
    }
    loadFont(font) {
        this.service.loadFont(font);
    }
    uploadFont() {
        this.fontPickerUpload.emit();
    }
    openDialog() {
        if (!this.dialog || !this.dialog.open) {
            this.toggleDialog();
        }
    }
    closeDialog() {
        if (this.dialog && this.dialog.open) {
            this.toggleDialog();
        }
    }
    toggleDialog() {
        if (!this.dialog) {
            let vcRef = this.vcRef;
            if (this.fpUseRootViewContainer && this.fpDialogDisplay !== 'inline') {
                const classOfRootComponent = this.appRef.componentTypes[0];
                const appInstance = this.injector.get(classOfRootComponent);
                vcRef = appInstance.vcRef || appInstance.viewContainerRef || this.vcRef;
                if (vcRef === this.vcRef) {
                    console.warn('You are using fpUseRootViewContainer, ' +
                        'but the root component is not exposing viewContainerRef!' +
                        'Please expose it by adding \'public vcRef: ViewContainerRef\' to the constructor.');
                }
            }
            const compFactory = this.resolver.resolveComponentFactory(FontPickerComponent);
            const injector = ReflectiveInjector.fromResolvedProviders([], vcRef.parentInjector);
            this.dialog = vcRef.createComponent(compFactory, 0, injector, []).instance;
            this.dialog.setDialog(this, this.elRef, this.fpUseRootViewContainer, this.fontPicker, this.fpWidth, this.fpHeight, this.fpDialogDisplay, this.fpSizeSelect, this.fpStyleSelect, this.fpPosition, this.fpPositionOffset, this.fpPositionRelativeToArrow, this.fpSearchText, this.fpLoadingText, this.fpPopularLabel, this.fpResultsLabel, this.fpPresetLabel, this.fpPresetFonts, this.fpPresetNotice, this.fpCancelButton, this.fpCancelButtonText, this.fpCancelButtonClass, this.fpUploadButton, this.fpUploadButtonText, this.fpUploadButtonClass, this.fpFilterByFamilies, this.fpSortByFamilies);
        }
        else if (!this.dialog.open) {
            this.dialog.updateDialog(this.fontPicker, this.fpWidth, this.fpHeight, this.fpDialogDisplay, this.fpSizeSelect, this.fpStyleSelect, this.fpPosition, this.fpPositionOffset, this.fpPositionRelativeToArrow, this.fpSearchText, this.fpLoadingText, this.fpPopularLabel, this.fpResultsLabel, this.fpPresetLabel, this.fpPresetFonts, this.fpPresetNotice, this.fpCancelButton, this.fpCancelButtonText, this.fpCancelButtonClass, this.fpUploadButton, this.fpUploadButtonText, this.fpUploadButtonClass, this.fpFilterByFamilies, this.fpSortByFamilies);
            this.dialog.openFontPicker();
        }
        else {
            this.dialog.closeFontPicker();
        }
    }
    fontChanged(font) {
        this.fontPickerChange.emit(font);
        this.cdRef.markForCheck();
        this.cdRef.detectChanges();
    }
}
FontPickerDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerDirective, deps: [{ token: i0.Injector }, { token: i0.ComponentFactoryResolver }, { token: i0.ApplicationRef }, { token: i0.ViewContainerRef }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: FontPickerService }], target: i0.ɵɵFactoryTarget.Directive });
FontPickerDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.3", type: FontPickerDirective, selector: "[fontPicker]", inputs: { fontPicker: "fontPicker", fpWidth: "fpWidth", fpHeight: "fpHeight", fpFallbackFont: "fpFallbackFont", fpAutoLoad: "fpAutoLoad", fpPresetLabel: "fpPresetLabel", fpPresetFonts: "fpPresetFonts", fpPresetNotice: "fpPresetNotice", fpSizeSelect: "fpSizeSelect", fpStyleSelect: "fpStyleSelect", fpDialogDisplay: "fpDialogDisplay", fpUseRootViewContainer: "fpUseRootViewContainer", fpPosition: "fpPosition", fpPositionOffset: "fpPositionOffset", fpPositionRelativeToArrow: "fpPositionRelativeToArrow", fpSearchText: "fpSearchText", fpLoadingText: "fpLoadingText", fpPopularLabel: "fpPopularLabel", fpResultsLabel: "fpResultsLabel", fpCancelButton: "fpCancelButton", fpCancelButtonText: "fpCancelButtonText", fpCancelButtonClass: "fpCancelButtonClass", fpUploadButton: "fpUploadButton", fpUploadButtonText: "fpUploadButtonText", fpUploadButtonClass: "fpUploadButtonClass", fpFilterByFamilies: "fpFilterByFamilies", fpSortByFamilies: "fpSortByFamilies" }, outputs: { fontPickerUpload: "fontPickerUpload", fontPickerChange: "fontPickerChange" }, host: { listeners: { "click": "onClick()" } }, exportAs: ["ngxFontPicker"], usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[fontPicker]',
                    exportAs: 'ngxFontPicker'
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i0.ComponentFactoryResolver }, { type: i0.ApplicationRef }, { type: i0.ViewContainerRef }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: FontPickerService }]; }, propDecorators: { fontPicker: [{
                type: Input,
                args: ['fontPicker']
            }], fpWidth: [{
                type: Input,
                args: ['fpWidth']
            }], fpHeight: [{
                type: Input,
                args: ['fpHeight']
            }], fpFallbackFont: [{
                type: Input,
                args: ['fpFallbackFont']
            }], fpAutoLoad: [{
                type: Input,
                args: ['fpAutoLoad']
            }], fpPresetLabel: [{
                type: Input,
                args: ['fpPresetLabel']
            }], fpPresetFonts: [{
                type: Input,
                args: ['fpPresetFonts']
            }], fpPresetNotice: [{
                type: Input,
                args: ['fpPresetNotice']
            }], fpSizeSelect: [{
                type: Input,
                args: ['fpSizeSelect']
            }], fpStyleSelect: [{
                type: Input,
                args: ['fpStyleSelect']
            }], fpDialogDisplay: [{
                type: Input,
                args: ['fpDialogDisplay']
            }], fpUseRootViewContainer: [{
                type: Input,
                args: ['fpUseRootViewContainer']
            }], fpPosition: [{
                type: Input,
                args: ['fpPosition']
            }], fpPositionOffset: [{
                type: Input,
                args: ['fpPositionOffset']
            }], fpPositionRelativeToArrow: [{
                type: Input,
                args: ['fpPositionRelativeToArrow']
            }], fpSearchText: [{
                type: Input,
                args: ['fpSearchText']
            }], fpLoadingText: [{
                type: Input,
                args: ['fpLoadingText']
            }], fpPopularLabel: [{
                type: Input,
                args: ['fpPopularLabel']
            }], fpResultsLabel: [{
                type: Input,
                args: ['fpResultsLabel']
            }], fpCancelButton: [{
                type: Input,
                args: ['fpCancelButton']
            }], fpCancelButtonText: [{
                type: Input,
                args: ['fpCancelButtonText']
            }], fpCancelButtonClass: [{
                type: Input,
                args: ['fpCancelButtonClass']
            }], fpUploadButton: [{
                type: Input,
                args: ['fpUploadButton']
            }], fpUploadButtonText: [{
                type: Input,
                args: ['fpUploadButtonText']
            }], fpUploadButtonClass: [{
                type: Input,
                args: ['fpUploadButtonClass']
            }], fpFilterByFamilies: [{
                type: Input,
                args: ["fpFilterByFamilies"]
            }], fpSortByFamilies: [{
                type: Input,
                args: ["fpSortByFamilies"]
            }], fontPickerUpload: [{
                type: Output,
                args: ['fontPickerUpload']
            }], fontPickerChange: [{
                type: Output,
                args: ['fontPickerChange']
            }], onClick: [{
                type: HostListener,
                args: ['click']
            }] } });

class FontPickerModule {
}
FontPickerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
FontPickerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.3", ngImport: i0, type: FontPickerModule, declarations: [FontPickerComponent, FontPickerDirective, FontSizePipe, FontStylesPipe, StatefulSlicePipe], imports: [CommonModule, HttpClientModule, FormsModule, ReactiveFormsModule,
        NgScrollbarModule, NgScrollbarReachedModule], exports: [FormsModule, ReactiveFormsModule, FontPickerDirective, FontSizePipe, FontStylesPipe, StatefulSlicePipe] });
FontPickerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerModule, providers: [FontPickerService], imports: [CommonModule, HttpClientModule, FormsModule, ReactiveFormsModule,
        NgScrollbarModule, NgScrollbarReachedModule, FormsModule, ReactiveFormsModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.3", ngImport: i0, type: FontPickerModule, decorators: [{
            type: NgModule,
            args: [{
                    entryComponents: [FontPickerComponent],
                    declarations: [FontPickerComponent, FontPickerDirective, FontSizePipe, FontStylesPipe, StatefulSlicePipe],
                    imports: [CommonModule, HttpClientModule, FormsModule, ReactiveFormsModule,
                        NgScrollbarModule, NgScrollbarReachedModule],
                    exports: [FormsModule, ReactiveFormsModule, FontPickerDirective, FontSizePipe, FontStylesPipe, StatefulSlicePipe],
                    providers: [FontPickerService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { FONT_PICKER_CONFIG, Font, FontPickerComponent, FontPickerConfig, FontPickerDirective, FontPickerModule, FontPickerService, FontSizePipe, FontStylesPipe, GoogleFontsInterface, StatefulSlicePipe };
//# sourceMappingURL=ngx-font-picker.mjs.map
